@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Itself
 #
-# This software is Copyright (c) 2007-2016 by Dominique Dumont.
+# This software is Copyright (c) 2007-2017 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # ABSTRACT: Edit the configuration of an application
 
 package App::Cme::Command::meta ;
-$App::Cme::Command::meta::VERSION = '2.004';
+$App::Cme::Command::meta::VERSION = '2.007';
 use strict ;
 use warnings ;
 use 5.10.1;
@@ -94,7 +94,7 @@ sub opt_spec {
 sub usage_desc {
   my ($self) = @_;
   my $desc = $self->SUPER::usage_desc; # "%c COMMAND %o"
-  return "$desc [ edit | gendot | dump | yaml ] your_model_class ";
+  return "$desc [ ".join(' | ', sort keys %meta_cmd)." ] your_model_class ";
 }
 
 sub description {
@@ -157,7 +157,7 @@ sub load_meta_model {
     my $system_cm_lib_dir = $INC{'Config/Model.pm'} ;
     $system_cm_lib_dir =~ s/\.pm//;
 
-    return ($meta_inst, $meta_root, $cm_lib_dir, $system_cm_lib_dir);
+    return ($meta_inst, $meta_root, $cm_lib_dir, path($system_cm_lib_dir));
 }
 
 sub load_meta_root {
@@ -206,14 +206,21 @@ sub load_meta_plugin {
     my ($meta_inst, $meta_root, $cm_lib_dir, $system_cm_lib_dir) = $self->load_meta_model($opt, $args);
 
     my $root_model = $opt->{_root_model};
-    my $meta_cm_lib_dir = $system_cm_lib_dir ;
-    my $plugin_file = shift @$args or die "missing plugin file name after application name.";
+    my $meta_cm_lib_dir = $opt->dev ? $cm_lib_dir : $system_cm_lib_dir ;
+    my $plugin_name = shift @$args or die "missing plugin file name after application name.";
+
+    if ($plugin_name =~ s/\.pl$//) {
+        warn "removed '.pl' deprecated suffix from plugin name\n";
+    }
+
+    say "Preparing plugin $plugin_name for model $root_model found in $meta_cm_lib_dir";
+    say "Use -dev option to create a plugin for a local model (i.e. in $cm_lib_dir)"
+        unless $opt->dev;
 
-    say "Preparing plugin for model $root_model";
     # now load model
     my $rw_obj = Config::Model::Itself -> new(
         model_object => $meta_root,
-        cm_lib_dir   => $meta_cm_lib_dir,
+        cm_lib_dir   => $meta_cm_lib_dir->canonpath,
     ) ;
 
     $meta_inst->initial_load_start ;
@@ -228,16 +235,20 @@ sub load_meta_plugin {
     $meta_inst->layered_stop;
 
     # load any existing plugin file
-    $rw_obj->read_model_snippet(snippet_dir => $cm_lib_dir, model_file => $plugin_file) ;
+    $rw_obj->read_model_plugin(
+        plugin_dir => $cm_lib_dir.'/models/',
+        plugin_name => $plugin_name
+    ) ;
 
     $meta_inst->initial_load_stop ;
 
     $self->load_optional_data($args, $opt, $root_model, $meta_root) ;
-
+    my $root_model_dir = $root_model ;
+    $root_model_dir =~ s!::!/!g;
     my $write_sub = sub {
-            $rw_obj->write_model_snippet(
-                snippet_dir => $cm_lib_dir,
-                model_file => $plugin_file
+            $rw_obj->write_model_plugin(
+                plugin_dir => "$cm_lib_dir/models/$root_model_dir.d",
+                plugin_name => $plugin_name
             );
         } ;
 
@@ -394,7 +405,7 @@ App::Cme::Command::meta - Edit the configuration of an application
 
 =head1 VERSION
 
-version 2.004
+version 2.007
 
 =head1 SYNOPSIS
 
@@ -405,7 +416,7 @@ version 2.004
   cme meta [ options ] check [ model_class ]
 
   # model plugin mode
-  cme meta [options] plugin Debian::Dpkg dpkg-snippet.pl
+  cme meta [options] plugin application plugin_name
 
 =head1 DESCRIPTION
 
@@ -442,16 +453,19 @@ C<./lib/Config/Model/models> directory and checks their validity.
 =head2 plugin
 
 This sub command is used to create model plugins. A model plugin is an
-addendum to an existing model. The resulting file will be saved in a
+addendum to an existing model. The resulting file is saved in a
 C<.d> directory besides the original file to be taken into account.
 
 For instance:
 
- $ cme meta plugin Debian::Dpkg my-plugin.pl
- # perform additions to Debian::Dpkg and Debian::Dpkg::Control::Source and save
- $ find lib -name my-plugin.pl
- lib/Config/Model/models/Debian/Dpkg.d/my-plugin.pl
- lib/Config/Model/models/Debian/Dpkg/Control/Source.d/my-plugin.pl
+ $ cme meta plugin dpkg my-plugin
+ # perform additions to Dpkg and Dpkg::Control and save
+ $ find lib/Config/Model/models/Dpkg.d -type f
+ lib/Config/Model/models/Debian/Dpkg.d/my-plugin/Dpkg.pl
+ lib/Config/Model/models/Debian/Dpkg.d/my-plugin/Dpkg/Control.pl
+
+Use C<-dev> option if you need to add plugins to a model located in
+current directory.
 
 =head2 gen-dot [ file.dot ]
 
@@ -567,10 +581,10 @@ model. (which explains the "Itself" name. This module could also be
 named C<Config::Model::DogFooding>).
 
 This explains why the GUI shown by C<cme meta edit> looks like the GUI
-shown by C<cme edit>: the same GUI generator is used>.
+shown by C<cme edit>: the same GUI generator is used.
 
 If you're new to L<Config::Model>, I'd advise not to peek under
-C<Config::Model::Itself> hood lest you'll loose your sanity.
+C<Config::Model::Itself> hood lest you loose your sanity.
 
 =head1 AUTHOR
 
@@ -628,7 +642,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2007-2016 by Dominique Dumont.
+This software is Copyright (c) 2007-2017 by Dominique Dumont.
 
 This is free software, licensed under:
 
