@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Itself
 #
-# This software is Copyright (c) 2007-2016 by Dominique Dumont.
+# This software is Copyright (c) 2007-2017 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -20,6 +20,16 @@
                 value_type => 'reference',
                 description => 'Top class required to configure this application',
             },
+            synopsis => {
+                type => 'leaf',
+                value_type => 'uniline',
+                description => "one line description of the application."
+            },
+            link_to_doc => {
+                type => 'leaf',
+                value_type => 'uniline',
+                description => "Documentation URL."
+            },
             category => {
                 choice => [
                     'system',
